@@ -524,7 +524,7 @@ class DnPropertyEncoder(BaseEncoder):
     static = False
     udm_module_name = ''
 
-    class DnStr(str):
+    class DnStr(str):  # noqa: SLOT000
         # a string with an additional member variable
         obj = None
 
